@@ -148,12 +148,14 @@ QPoint WindowSystem::desktopToViewport(int desktop, bool absolute)
     return QPoint();
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId WindowSystem::groupLeader(WId window)
 {
     Q_UNUSED(window)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support group leader";
     return 0;
 }
+#endif
 
 bool WindowSystem::icccmCompliantMappingState()
 {
@@ -349,9 +351,6 @@ void WindowSystem::clearState(WId win, NET::States state)
     if (state & NET::KeepAbove) {
         qCDebug(KWAYLAND_KWS) << "This plugin does not support changing KeepAbove window state";
     }
-    if (state & NET::StaysOnTop) {
-        qCDebug(KWAYLAND_KWS) << "This plugin does not support changing StaysOnTop window state";
-    }
     if (state & NET::SkipPager) {
         qCDebug(KWAYLAND_KWS) << "This plugin does not support changing SkipPager window state";
     }
@@ -410,9 +409,6 @@ void WindowSystem::setState(WId win, NET::States state)
     if (state & NET::KeepAbove) {
         qCDebug(KWAYLAND_KWS) << "This plugin does not support changing KeepAbove window state";
     }
-    if (state & NET::StaysOnTop) {
-        qCDebug(KWAYLAND_KWS) << "This plugin does not support changing StaysOnTop window state";
-    }
     if (state & NET::SkipPager) {
         qCDebug(KWAYLAND_KWS) << "This plugin does not support changing SkipPager window state";
     }
@@ -497,12 +493,14 @@ QList< WId > WindowSystem::stackingOrder()
     return ret;
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId WindowSystem::transientFor(WId window)
 {
     Q_UNUSED(window)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support transient for windows";
     return 0;
 }
+#endif
 
 int WindowSystem::viewportToDesktop(const QPoint &pos)
 {
